==> bigloo2.9a.tar.gz: bigloo2.9a/api/pthread/src/Llib/pmutex.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/api/pthread/src/Llib/pmutex.scm      */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Nov  3 08:14:49 2004                          */
;*    Last change :  Tue Apr 12 09:20:44 2005 (serrano)                */
;*    Copyright   :  2004-05 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The public Posix Mutex implementation.                           */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __pth_mutex

   (include "pmutex.sch")
   
   (export (mutex-state ::mutex)
	   (mutex-specific::obj ::mutex)
	   (mutex-specific-set!::obj ::mutex ::obj)))

;*---------------------------------------------------------------------*/
;*    mutex-state ...                                                  */
;*---------------------------------------------------------------------*/
(define (mutex-state mutex)
   ($pmutex-state mutex))

;*---------------------------------------------------------------------*/
;*    mutex-specific ...                                               */
;*---------------------------------------------------------------------*/
(define (mutex-specific m)
   ($pmutex-specific m))

;*---------------------------------------------------------------------*/
;*    mutex-specific-set! ...                                          */
;*---------------------------------------------------------------------*/
(define (mutex-specific-set! m v)
   ($pmutex-specific-set! m v)
   v)

==> bigloo3.1a.tar.gz: bigloo3.1a/api/pthread/src/Llib/pmutex.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/api/pthread/src/Llib/pmutex.scm      */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Nov  3 08:14:49 2004                          */
;*    Last change :  Sat May  3 06:17:18 2008 (serrano)                */
;*    Copyright   :  2004-08 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The public Posix Mutex implementation.                           */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __pth_mutex

   (include "pmutex.sch")
   
   (export (mutex-specific::obj ::mutex)
	   (mutex-specific-set!::obj ::mutex ::obj)))

;*---------------------------------------------------------------------*/
;*    mutex-specific ...                                               */
;*---------------------------------------------------------------------*/
(define (mutex-specific m)
   ($pmutex-specific m))

;*---------------------------------------------------------------------*/
;*    mutex-specific-set! ...                                          */
;*---------------------------------------------------------------------*/
(define (mutex-specific-set! m v)
   ($pmutex-specific-set! m v)
   v)
